@@ -160,8 +160,9 @@ impl<T: SetAttributes + Draw> ElementInner<T> {
         self.class.as_deref()
     }
 
-    fn inherit_xml_lang(&mut self) {
-        self.specified_values.inherit_xml_lang(&mut self.values);
+    fn inherit_xml_lang(&mut self, parent: Option<Node>) {
+        self.specified_values
+            .inherit_xml_lang(&mut self.values, parent);
     }
 
     fn get_specified_values(&self) -> &SpecifiedValues {
@@ -501,8 +502,8 @@ impl Element {
         call_inner!(self, get_class)
     }
 
-    pub fn inherit_xml_lang(&mut self) {
-        call_inner!(self, inherit_xml_lang)
+    pub fn inherit_xml_lang(&mut self, parent: Option<Node>) {
+        call_inner!(self, inherit_xml_lang, parent)
     }
 
     pub fn get_specified_values(&self) -> &SpecifiedValues {
@@ -805,80 +806,3 @@ static ELEMENT_CREATORS: Lazy<HashMap<&'static str, (ElementCreateFn, ElementCre
 
     creators_table.into_iter().map(|(n, c, f)| (n, (c, f))).collect()
 });
-
-#[cfg(ignore)]
-mod sizes {
-    //! This module is in this file just because here we have all the imports.
-
-    use super::*;
-
-    macro_rules! print_size {
-        ($ty:ty) => {
-            println!("sizeof {}: {}", stringify!($ty), mem::size_of::<$ty>());
-        };
-    }
-
-    pub fn print_sizes() {
-        use crate::properties::{ComputedValues, ParsedProperty, SpecifiedValues};
-        use std::mem;
-
-        print_size!(NodeData);
-        print_size!(Element);
-        print_size!(SpecifiedValues);
-        print_size!(ComputedValues);
-        print_size!(ParsedProperty);
-
-        print_size!(Circle);
-        print_size!(ClipPath);
-        print_size!(NonRendering);
-        print_size!(Ellipse);
-        print_size!(FeBlend);
-        print_size!(FeColorMatrix);
-        print_size!(FeComponentTransfer);
-        print_size!(FeFuncA);
-        print_size!(FeFuncB);
-        print_size!(FeFuncG);
-        print_size!(FeFuncR);
-        print_size!(FeComposite);
-        print_size!(FeConvolveMatrix);
-        print_size!(FeDiffuseLighting);
-        print_size!(FeDistantLight);
-        print_size!(FeDisplacementMap);
-        print_size!(FeFlood);
-        print_size!(FeGaussianBlur);
-        print_size!(FeImage);
-        print_size!(FeMerge);
-        print_size!(FeMergeNode);
-        print_size!(FeMorphology);
-        print_size!(FeOffset);
-        print_size!(FePointLight);
-        print_size!(FeSpecularLighting);
-        print_size!(FeSpotLight);
-        print_size!(FeTile);
-        print_size!(FeTurbulence);
-        print_size!(Filter);
-        print_size!(Group);
-        print_size!(Image);
-        print_size!(Line);
-        print_size!(LinearGradient);
-        print_size!(Link);
-        print_size!(Marker);
-        print_size!(Mask);
-        print_size!(NonRendering);
-        print_size!(Path);
-        print_size!(Pattern);
-        print_size!(Polygon);
-        print_size!(Polyline);
-        print_size!(RadialGradient);
-        print_size!(Rect);
-        print_size!(Stop);
-        print_size!(Style);
-        print_size!(Svg);
-        print_size!(Switch);
-        print_size!(Symbol);
-        print_size!(Text);
-        print_size!(TRef);
-        print_size!(TSpan);
-        print_size!(Use);
-    }
-}
