@@ -16,6 +16,9 @@ mod errors;
 #[cfg(test)]
 mod filters;
 
+#[cfg(test)]
+mod geometries;
+
 #[cfg(test)]
 mod intrinsic_dimensions;
 
@@ -28,6 +31,9 @@ mod loading_crash;
 #[cfg(test)]
 mod predicates;
 
+#[cfg(test)]
+mod primitive_geometries;
+
 #[cfg(test)]
 mod primitives;
 
