@@ -1,8 +1,10 @@
-use chrono::{DateTime, Utc};
+use chrono::{DateTime, Local, Utc};
+use float_cmp::approx_eq;
 use lopdf::{self, Dictionary, Object};
 use predicates::prelude::*;
 use predicates::reflection::{Case, Child, PredicateReflection, Product};
 use std::cmp;
+use std::convert::TryFrom;
 use std::fmt;
 
 /// Checks that the variable of type [u8] can be parsed as a PDF file.
@@ -20,8 +22,8 @@ impl PdfPredicate {
     pub fn with_page_size(
         self: Self,
         idx: usize,
-        width_in_points: f64,
-        height_in_points: f64,
+        width_in_points: f32,
+        height_in_points: f32,
     ) -> DetailPredicate<Self> {
         DetailPredicate::<Self> {
             p: self,
@@ -49,6 +51,13 @@ impl PdfPredicate {
             d: Detail::Link(link.to_string()),
         }
     }
+
+    pub fn with_text(self: Self, text: &str) -> DetailPredicate<Self> {
+        DetailPredicate::<Self> {
+            p: self,
+            d: Detail::Text(text.to_string()),
+        }
+    }
 }
 
 impl Predicate<[u8]> for PdfPredicate {
@@ -85,6 +94,7 @@ enum Detail {
     PageSize(Dimensions, usize),
     CreationDate(DateTime<Utc>),
     Link(String),
+    Text(String),
 }
 
 /// A PDF page's dimensions from its `MediaBox`.
@@ -92,13 +102,13 @@ enum Detail {
 /// Note that `w` and `h` given in `UserUnit`, which is by default 1.0 = 1/72 inch.
 #[derive(Debug)]
 struct Dimensions {
-    w: f64,
-    h: f64,
-    unit: f64, // UserUnit, in points (1/72 of an inch)
+    w: f32,
+    h: f32,
+    unit: f32, // UserUnit, in points (1/72 of an inch)
 }
 
 impl Dimensions {
-    pub fn from_media_box(obj: &lopdf::Object, unit: Option<f64>) -> lopdf::Result<Dimensions> {
+    pub fn from_media_box(obj: &lopdf::Object, unit: Option<f32>) -> lopdf::Result<Dimensions> {
         let a = obj.as_array()?;
         Ok(Dimensions {
             w: a[2].as_float()?,
@@ -107,11 +117,11 @@ impl Dimensions {
         })
     }
 
-    pub fn width_in_pt(self: &Self) -> f64 {
+    pub fn width_in_pt(self: &Self) -> f32 {
         self.w * self.unit
     }
 
-    pub fn height_in_pt(self: &Self) -> f64 {
+    pub fn height_in_pt(self: &Self) -> f32 {
         self.h * self.unit
     }
 }
@@ -125,15 +135,15 @@ impl fmt::Display for Dimensions {
 impl cmp::PartialEq for Dimensions {
     fn eq(&self, other: &Self) -> bool {
         approx_eq!(
-            f64,
+            f32,
             self.width_in_pt(),
             other.width_in_pt(),
-            epsilon = 0.000_001
+            epsilon = 0.0001
         ) && approx_eq!(
-            f64,
+            f32,
             self.height_in_pt(),
             other.height_in_pt(),
-            epsilon = 0.000_001
+            epsilon = 0.0001
         )
     }
 }
@@ -159,6 +169,7 @@ impl DetailPredicate<PdfPredicate> {
             Detail::PageSize(d, idx) => doc.get_page_size(*idx).map_or(false, |dim| dim == *d),
             Detail::CreationDate(d) => doc.get_creation_date().map_or(false, |date| date == *d),
             Detail::Link(link) => document_has_link(doc, &link),
+            Detail::Text(text) => document_has_text(doc, &text),
         }
     }
 
@@ -192,23 +203,9 @@ impl DetailPredicate<PdfPredicate> {
                 "actual link contents",
                 "FIXME: who knows, but it's not what we expected".to_string(),
             ),
-        }
-    }
-}
-
-// Extensions to lopdf::Object; can be removed after lopdf 0.26
-trait ObjExt {
-    /// Get the object value as a float.
-    /// Unlike as_f64() this will also cast an Integer to a Real.
-    fn as_float(&self) -> lopdf::Result<f64>;
-}
-
-impl ObjExt for lopdf::Object {
-    fn as_float(&self) -> lopdf::Result<f64> {
-        match *self {
-            lopdf::Object::Integer(ref value) => Ok(*value as f64),
-            lopdf::Object::Real(ref value) => Ok(*value),
-            _ => Err(lopdf::Error::Type),
+            Detail::Text(_) => {
+                Product::new("actual text contents", doc.extract_text(&[1]).unwrap())
+            }
         }
     }
 }
@@ -223,7 +220,7 @@ impl Details for lopdf::Document {
             Ok(obj) => {
                 let unit = self
                     .get_from_page(idx, b"UserUnit")
-                    .and_then(ObjExt::as_float)
+                    .and_then(Object::as_float)
                     .ok();
                 Dimensions::from_media_box(obj, unit).ok()
             }
@@ -233,7 +230,15 @@ impl Details for lopdf::Document {
 
     fn get_creation_date(self: &Self) -> Option<DateTime<Utc>> {
         match self.get_from_trailer(b"CreationDate") {
-            Ok(obj) => obj.as_datetime().map(|date| date.with_timezone(&Utc)),
+            Ok(obj) => match obj.as_datetime() {
+                Some(d) => {
+                    let local_datetime = DateTime::<Local>::try_from(d).ok()?;
+                    Some(local_datetime.into())
+                }
+
+                None => None,
+            },
+
             Err(_) => None,
         }
     }
@@ -254,7 +259,7 @@ impl Details for lopdf::Document {
         }
         match iter.next() {
             Some(id) => self.get_object(id)?.as_dict()?.get(key),
-            None => Err(lopdf::Error::ObjectNotFound),
+            None => Err(lopdf::Error::PageNumberNotFound(idx as u32)),
         }
     }
 }
@@ -289,10 +294,21 @@ impl fmt::Display for DetailPredicate<PdfPredicate> {
             Detail::PageSize(d, _) => write!(f, "is a PDF sized {}", d),
             Detail::CreationDate(d) => write!(f, "is a PDF created {:?}", d),
             Detail::Link(l) => write!(f, "is a PDF with a link to {}", l),
+            Detail::Text(t) => write!(f, "is a PDF with \"{}\" in its text content", t),
         }
     }
 }
 
+// This is an extremely trivial test for a string being present in the document's
+// text objects.
+fn document_has_text(document: &lopdf::Document, needle: &str) -> bool {
+    if let Ok(haystack) = text_from_first_page(document) {
+        haystack.contains(needle)
+    } else {
+        false
+    }
+}
+
 // We do a super simple test that a PDF actually contains an Annotation object
 // with a particular link.  We don't test that this annotation is actually linked
 // from a page; that would be nicer.
@@ -313,8 +329,8 @@ fn object_is_annotation_with_link(object: &Object, link_text: &str) -> bool {
 
 fn dict_is_annotation(dict: &Dictionary) -> bool {
     dict.get(b"Type")
-        .and_then(|type_val| type_val.as_name_str())
-        .map(|name| name == "Annot")
+        .and_then(|type_val| type_val.as_name())
+        .map(|name| name == b"Annot")
         .unwrap_or(false)
 }
 
@@ -326,3 +342,9 @@ fn dict_has_a_with_link(dict: &Dictionary, link_text: &str) -> bool {
         .map(|string| string == link_text.as_bytes())
         .unwrap_or(false)
 }
+
+fn text_from_first_page(doc: &lopdf::Document) -> lopdf::Result<String> {
+    // This is extremely simplistic; lopdf just concatenates all the text in the page
+    // into a single string.
+    doc.extract_text(&[1])
+}
